
## PySceneDetect CLI Reference

The `scenedetect` command reference is available as part of [the PySceneDetect Manual](http://manual.scenedetect.com/):

 - [`scenedetect` Options](http://manual.scenedetect.com/en/v0.6/cli/global_options.html)
 - [Command Reference](http://manual.scenedetect.com/en/v0.6/cli/commands.html)
 - [Detector Reference](http://manual.scenedetect.com/en/v0.6/cli/detectors.html)

You can also run `scenedetect help all` locally for the full `scenedetect command reference.
